boldify_icon library
Classes
- BoldifyIcon
- A graphical icon widget drawn with a glyph from a font described in an IconData, similar to Flutter’s built-in Icon, but with an extra fontWeight property to allow rendering bold icons or matching the weight of surrounding text.